@@ -1,6 +1,6 @@
 /* append.h -- Description of messages to be copied 
- $Id: append.h,v 1.21 2002/03/13 21:39:17 ken3 Exp $ 
-
+ * $Id: append.h,v 1.26 2004/01/22 21:17:07 ken3 Exp $ 
+ *
  * Copyright (c) 1998, 2000 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -45,6 +45,7 @@
 #ifndef INCLUDED_APPEND_H
 #define INCLUDED_APPEND_H
 
+#include "mailbox.h"
 #include "prot.h"
 
 struct copymsg {
@@ -53,6 +54,8 @@ struct copymsg {
     time_t sentdate;
     unsigned long size;
     unsigned long header_size;
+    unsigned long content_lines;
+    unsigned long cache_version;
     const char *cache_begin;
     int cache_len;		/* 0 if need to copy & parse message */
     int seen;
@@ -65,7 +68,7 @@ struct copymsg {
 struct appendstate {
     /* mailbox we're appending to */
     struct mailbox m;
-    char userid[MAX_MAILBOX_NAME];
+    char userid[MAX_MAILBOX_NAME+1];
 
     enum { APPEND_READY, APPEND_DONE } s;
 				/* current state of append */
@@ -87,6 +90,9 @@ struct appendstate {
 
     /* the amount of quota we've used so far in this append */
     int quota_used;
+
+    /* txn for updating quota */
+    struct txn *tid;
 };
 
 /* add helper function to determine uid range appended? */
@@ -104,6 +110,7 @@ extern int append_setup(struct appendstate *mailbox, const char *name,
 			long aclcheck, long quotacheck);
 
 extern int append_commit(struct appendstate *mailbox,
+			 long quotacheck,
 			 unsigned long *uidvalidity, 
 			 unsigned long *startuid, 
 			 unsigned long *num);
@@ -113,14 +120,12 @@ int append_stageparts(struct stagemsg *stagep);
 
 /* creates a new stage and returns stage file corresponding to mailboxname */
 extern FILE *append_newstage(const char *mailboxname, time_t internaldate,
-			     struct stagemsg **stagep);
+			     int msgnum, struct stagemsg **stagep);
 
 /* adds a new mailbox to the stage initially created by append_newstage() */
 extern int append_fromstage(struct appendstate *mailbox,
-			    struct protstream *messagefile,
-			    unsigned long size, time_t internaldate,
-			    const char **flag, int nflags,
-			    struct stagemsg *stage);
+			    struct stagemsg *stage, time_t internaldate,
+			    const char **flag, int nflags, int nolink);
 
 /* removes the stage (frees memory, deletes the staging files) */
 extern int append_removestage(struct stagemsg *stage);
