@@ -1,6 +1,6 @@
 /* lmtpd.c -- Program to deliver mail to a mailbox
  *
- * $Id: lmtpd.c,v 1.137 2004/07/06 20:02:20 ken3 Exp $
+ * $Id: lmtpd.c,v 1.139 2004/09/09 16:21:26 shadow Exp $
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -239,9 +239,7 @@ int service_main(int argc, char **argv,
 	deliver_logfd = -1;
     }
 
-    cyrus_close_sock(0);
-    cyrus_close_sock(1);
-    cyrus_close_sock(2);
+    cyrus_reset_stdio(); 
 
     return 0;
 }
