@@ -1,5 +1,5 @@
 /* mailbox.c -- Mailbox manipulation routines
- * $Id: mailbox.c,v 1.159 2005/04/07 00:25:52 shadow Exp $
+ * $Id: mailbox.c,v 1.155 2004/05/22 03:45:51 rjs3 Exp $
  * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -187,7 +187,7 @@ int mailbox_cached_header(const char *s)
     /* Generate lower case copy of string */
     /* xxx sometimes the caller has already generated this .. 
      * maybe we can just require callers to do it? */
-    for (i=0 ; *s && (i < (MAX_CACHED_HEADER_SIZE - 1)) ; i++)
+    for (i=0 ; *s && (i < MAX_CACHED_HEADER_SIZE) ; i++)
 	hdr[i] = tolower(*s++);
     
     if (*s) return BIT32_MAX;   /* Input too long for match */
@@ -205,7 +205,7 @@ int mailbox_cached_header_inline(const char *text)
     int i;
     
     /* Scan for header */
-    for (i=0; i < (MAX_CACHED_HEADER_SIZE - 1); i++) {
+    for (i=0; i < MAX_CACHED_HEADER_SIZE; i++) {
 	if (!text[i] || text[i] == '\r' || text[i] == '\n') break;
 	
 	if (text[i] == ':') {
@@ -1780,12 +1780,6 @@ mailbox_expunge(struct mailbox *mailbox,
 	    
 	    cache_offset = ntohl(*((bit32 *)(buf+OFFSET_CACHE_OFFSET)));
 
-	    if (cache_offset == 0) {
-		syslog(LOG_ERR, "IOERROR: reading index header for %s: got 0 cache_offset on message %u/%lu; trying recovery",
-		       mailbox->name, msgno, mailbox->exists);
-		continue;
-	    }
-
 	    /* Fix up cache file offset */
 	    *((bit32 *)(buf+OFFSET_CACHE_OFFSET)) =
 		htonl(new_cache_total_size);
