@@ -72,7 +72,7 @@
  * may contain an explanatory message.
  *
  *
- * $Id: smmapd.c,v 1.8 2004/05/22 03:45:52 rjs3 Exp $
+ * $Id: smmapd.c,v 1.10 2004/09/09 16:21:28 shadow Exp $
  */
 
 #include <config.h>
@@ -119,9 +119,7 @@ void shut_down(int code)
     if (map_in) prot_free(map_in);
     if (map_out) prot_free(map_out);
 
-    cyrus_close_sock(0);
-    cyrus_close_sock(1);
-    cyrus_close_sock(2);
+    cyrus_reset_stdio(); 
 
     mboxlist_close();
     mboxlist_done();
