@@ -40,7 +40,7 @@
  *
  */
 /*
- * $Id: spool.c,v 1.5 2004/03/04 16:09:34 ken3 Exp $
+ * $Id: spool.c,v 1.7 2004/10/27 20:40:50 shadow Exp $
  */
 
 #include <config.h>
@@ -165,7 +165,7 @@ static int parseheader(struct protstream *fin, FILE *fout,
 		
 		if (peek == '\r' || peek == '\n') {
 		    /* just reached the end of message */
-		    r = IMAP_MESSAGE_NOBLANKLINE;
+		    r = 0;
 		    goto ph_error;
 		}
 	    }
@@ -451,7 +451,7 @@ int spool_copy_msg(struct protstream *fin, FILE *fout)
 	    p[1] = '\n';
 	    p[2] = '\0';
 	}
-	else if (p[0] != '\n') {
+	else if (p[0] != '\n' && (strlen(buf) < sizeof(buf)-2)) {
 	    /* line contained a \0 not at the end */
 	    r = IMAP_MESSAGE_CONTAINSNULL;
 	    continue;
